<?php

namespace Litepie\Psocform\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Psocform\Http\Requests\PsocformRequest;
use Litepie\Psocform\Interfaces\PsocformRepositoryInterface;
use Litepie\Psocform\Models\Psocform;
use Litepie\Psocform\Forms\Psocform as Form;

/**
 * APIController  class for psocform.
 */
class PsocformAPIController extends BaseController
{

    /**
     * Initialize psocform resource controller.
     *
     * @param type PsocformRepositoryInterface $psocform
     *
     * @return null
     */
    public function __construct(PsocformRepositoryInterface $psocform)
    {
        parent::__construct();
        $this->repository = $psocform;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Psocform\Repositories\Criteria\PsocformResourceCriteria::class);
    }

    /**
     * Display a list of psocform.
     *
     * @return Response
     */
    public function index(PsocformRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Psocform\Repositories\Presenter\PsocformPresenter::class)
            ->paginate();
    }

    /**
     * Display psocform.
     *
     * @param Request $request
     * @param Model   $psocform
     *
     * @return Response
     */
    public function show(PsocformRequest $request, Psocform $psocform)
    {
        return $psocform->setPresenter(\Litepie\Psocform\Repositories\Presenter\PsocformListPresenter::class);
        ;
    }

    /**
     * Create new psocform.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PsocformRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('psocform::psocform.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('psocform/psocform/' . $psocform->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('psocform/psocform');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the psocform.
     *
     * @param Request $request
     * @param Model   $psocform
     *
     * @return Response
     */
    public function update(PsocformRequest $request, Psocform $psocform)
    {
        try {
            $data = $request->all();

            $psocform->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('psocform::psocform.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('psocform/psocform/' . $psocform->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('psocform/psocform/' . $psocform->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the psocform.
     *
     * @param Model   $psocform
     *
     * @return Response
     */
    public function destroy(PsocformRequest $request, Psocform $psocform)
    {
        try {
            $psocform->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('psocform::psocform.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('psocform/psocform/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('psocform/psocform/' . $psocform->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
