<?php

namespace Litepie\Psocform\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Psocform\Models\Psocform;

class PsocformPolicy
{

    /**
     * Determine if the given user can view the psocform.
     *
     * @param UserPolicy $user
     * @param Psocform $psocform
     *
     * @return bool
     */
    public function view(UserPolicy $user, Psocform $psocform)
    {
        if ($user->canDo('psocform.psocform.view') && $user->isAdmin()) {
            return true;
        }

        return $psocform->user_id == user_id() && $psocform->user_type == user_type();
    }

    /**
     * Determine if the given user can create a psocform.
     *
     * @param UserPolicy $user
     * @param Psocform $psocform
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('psocform.psocform.create');
    }

    /**
     * Determine if the given user can update the given psocform.
     *
     * @param UserPolicy $user
     * @param Psocform $psocform
     *
     * @return bool
     */
    public function update(UserPolicy $user, Psocform $psocform)
    {
        if ($user->canDo('psocform.psocform.edit') && $user->isAdmin()) {
            return true;
        }

        return $psocform->user_id == user_id() && $psocform->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given psocform.
     *
     * @param UserPolicy $user
     * @param Psocform $psocform
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Psocform $psocform)
    {
        return $psocform->user_id == user_id() && $psocform->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given psocform.
     *
     * @param UserPolicy $user
     * @param Psocform $psocform
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Psocform $psocform)
    {
        if ($user->canDo('psocform.psocform.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given psocform.
     *
     * @param UserPolicy $user
     * @param Psocform $psocform
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Psocform $psocform)
    {
        if ($user->canDo('psocform.psocform.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
